import tkinter as tk
from tkinter import messagebox

class ComputerQuiz:
    def __init__(self, root):
        self.root = root
        self.root.title("Test wiedzy o komputerach")
        self.score = 0
        self.question_number = 0

        # Pytania
        self.questions = [
            {
                "question": "Co oznacza CPU?",
                "options": ["Central Processing Unit", "Central Power Unit", "Control Processing Unit", "Computer Personal Unit"],
                "answer": "Central Processing Unit"
            },
            {
                "question": "Który z poniższych jest językiem programowania?",
                "options": ["Windows", "Python", "RTX", "ChromeOS Flex"],
                "answer": "Python"
            },
            {
                "question": "Co to jest RAM?",
                "options": ["Random Access Memory", "Read Access Memory", "Run Access Memory", "Restore Access Memory"],
                "answer": "Random Access Memory"
            },
            {
                "question": "Co to jest GPU?",
                "options": ["Graphics Processing Unit", "Graphical Power Unit", "Graphics Personal Unit", "Graph Processor Unit"],
                "answer": "Graphics Processing Unit"
            },
            {
                "question": "Co oznacza skrót SSD?",
                "options": ["Solid State Drive", "System Software Drive", "Secure Storage Disk", "Super Speed Drive"],
                "answer": "Solid State Drive"
            },
            {
                "question": "Która firma stworzyła system operacyjny Windows?",
                "options": ["Apple", "Google", "Microsoft", "IBM"],
                "answer": "Microsoft"
            },
            {
                "question": "Który z poniższych to system operacyjny?",
                "options": ["Windows", "Intel", "MS Office", "Python"],
                "answer": "Windows"
            },
            {
                "question": "Co to jest BIOS?",
                "options": ["Basic Input/Output System", "Binary Input/Output System", "Booting Input/Output System", "Basic Integrated Operating System"],
                "answer": "Basic Input/Output System"
            },
            {
                "question": "Który z poniższych elementów przechowuje dane nawet po wyłączeniu zasilania?",
                "options": ["RAM", "GPU", "CPU", "SSD"],
                "answer": "SSD"
            },
            {
                "question": "Który protokół jest używany do przeglądania stron internetowych?",
                "options": ["FTP", "HTTP", "SMTP", "TCP"],
                "answer": "HTTP"
            }
        ]

        self.create_widgets()
        self.load_question()

    def create_widgets(self):
        """Tworzy elementy interfejsu."""
        self.question_label = tk.Label(self.root, text="", font=("Arial", 16), wraplength=400)
        self.question_label.pack(pady=20)

        self.var = tk.StringVar()

        self.option_buttons = []
        for i in range(4):
            button = tk.Radiobutton(self.root, text="", variable=self.var, value="", font=("Arial", 12))
            button.pack(anchor="w", padx=20, pady=5)
            self.option_buttons.append(button)

        self.submit_button = tk.Button(self.root, text="Zatwierdź", command=self.check_answer, font=("Arial", 14))
        self.submit_button.pack(pady=20)

    def load_question(self):
        """Ładuje bieżące pytanie i opcje odpowiedzi."""
        if self.question_number < len(self.questions):
            current_question = self.questions[self.question_number]
            self.question_label.config(text=current_question["question"])

            self.var.set(None)  # Resetowanie wyboru odpowiedzi

            for i, option in enumerate(current_question["options"]):
                self.option_buttons[i].config(text=option, value=option)
        else:
            self.show_result()

    def check_answer(self):
        """Sprawdza poprawność odpowiedzi i przechodzi do kolejnego pytania."""
        selected_answer = self.var.get()
        correct_answer = self.questions[self.question_number]["answer"]

        if selected_answer == correct_answer:
            self.score += 1
        else:
            messagebox.showwarning("Zła odpowiedź", "zle !")
        
        self.question_number += 1
        self.load_question()

    def show_result(self):
        """Wyświetla wynik końcowy po zakończeniu quizu."""
        result_message = f"Twój wynik: {self.score}/{len(self.questions)}"
        messagebox.showinfo("Koniec testu", result_message)
        self.root.quit()

# Tworzenie okna głównego
root = tk.Tk()
quiz = ComputerQuiz(root)
root.mainloop()
